/*
 * Serializer for tagcolledit
 *
 * Copyright (C) 2005  Enrico Zini <enrico@debian.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#pragma implementation

#include "Serializer.h"
#include "Tag.h"
#include "TagSet.h"

using namespace std;

namespace Tagcoll
{

std::string Serializer<string, Tag>::tagToString(const Tag& tag) throw ()
{
	return tag.fullname();
}


Tag Serializer<string, Tag>::stringToTag(const std::string& tag) throw ()
{
	return _voc.obtainTag(tag);
}

OpSet<std::string> Serializer<string, Tag>::tagsToStrings(const OpSet<Tag>& tags) throw ()
{
	OpSet<std::string> res;
	
	for (OpSet<Tag>::const_iterator i = tags.begin();
			i != tags.end(); i++)
		if (*i != Tag())
			res += tagToString(*i);
	
	return res;
}

OpSet<Tag> Serializer<string, Tag>::stringsToTags(const OpSet<std::string>& tags) throw ()
{
	OpSet<Tag> res;
	
	for (OpSet<std::string>::const_iterator i = tags.begin();
			i != tags.end(); i++)
	{
		Tag t = stringToTag(*i);
		if (t != Tag())
			res += t;
	}
	
	return res;
}

};

// vim:set ts=4 sw=4:
